@@ -33,7 +33,7 @@ uwc_rss_setlocale();
    foreach ($this->get_rss() as $rss_item) { ?>
   <item>
      <title><?php echo uwc_format_escape_rss($rss_item["title"]); ?></title>
-     <description><?php echo uwc_format_escape_rss($rss_item["text"]); ?></description>
+     <description><?php echo uwc_format_escape_rss($rss_item["text"]); ?> ...</description>
      <pubDate><?php echo uwc_rss_date_from_unix_timestamp($rss_item["date_update"]); ?></pubDate>
      <link><?php echo $this->make_absolute_url_clean($rss_item["path"]); ?></link>
   </item>
